@@ -15,7 +15,7 @@ class ExperimentSignature(Entity):
 
         Returns
         -------
-        :class:`~labstep.experiment.ExperimentSignature`
+        :class:`~labstep.entities.experimentSignature.model.ExperimentSignature`
             An object representing the revoked signature.
         """
         from labstep.generic.entity.repository import entityRepository
