@@ -5,6 +5,7 @@
 from labstep.service.helpers import getTime
 from labstep.entities.organizationUser.model import OrganizationUser
 from labstep.generic.entity.repository import entityRepository
+from labstep.entities.user.model import User
 
 
 class OrganizationUserRepository:
@@ -36,7 +37,9 @@ class OrganizationUserRepository:
         params = {
             "deleted_at": getTime(),
         }
-        return entityRepository.editEntity(organizationUser, params)
+        user = User({"id": organizationUser.user['username']})
+        user.__user__ = organizationUser.__user__
+        return entityRepository.editEntity(user, params)
 
 
 organizationUserRepository = OrganizationUserRepository()
