@@ -221,3 +221,23 @@ class ResourceItem(Entity):
         from labstep.entities.metadata.repository import metadataRepository
 
         return metadataRepository.getMetadata(self)
+
+    def getData(self):
+        """
+        Returns data linked to this resource via experiments.
+
+        Returns
+        -------
+        List[:class:`~labstep.entities.experimentDataField.model.ExperimentDataField`]
+
+
+        Example
+        -------
+        ::
+
+            my_resource = user.getResource(17000)
+            my_resource.getData()
+        """
+        from labstep.entities.experimentDataField.repository import experimentDataFieldRepository
+
+        return experimentDataFieldRepository.getDataFields(self)
