@@ -18,7 +18,7 @@ class PrimaryEntity(ShareableEntity):
 
         Returns
         -------
-        :class:`~labstep.experiment.Experiment`
+        :class:`~labstep.entities.experiment.model.Experiment`
             The Experiment that was tagged.
 
         Example
@@ -39,7 +39,7 @@ class PrimaryEntity(ShareableEntity):
 
         Returns
         -------
-        List[:class:`~labstep.tag.Tag`]
+        List[:class:`~labstep.entities.tag.model.Tag`]
             List of the tags attached.
 
         Example
